==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/association/impl/ReferredToClassInAssocSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.association.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.association.ClassAsAssociatedOneSideSet;
import io.ciera.tool.sql.ooaofooa.association.ClassAsAssociatedOtherSideSet;
import io.ciera.tool.sql.ooaofooa.association.ClassAsSimpleParticipantSet;
import io.ciera.tool.sql.ooaofooa.association.ClassAsSupertypeSet;
import io.ciera.tool.sql.ooaofooa.association.ClassInAssociationSet;
import io.ciera.tool.sql.ooaofooa.association.ReferredToClassInAssoc;
import io.ciera.tool.sql.ooaofooa.association.ReferredToClassInAssocSet;
import io.ciera.tool.sql.ooaofooa.association.impl.ClassAsAssociatedOneSideSetImpl;
import io.ciera.tool.sql.ooaofooa.association.impl.ClassAsAssociatedOtherSideSetImpl;
import io.ciera.tool.sql.ooaofooa.association.impl.ClassAsSimpleParticipantSetImpl;
import io.ciera.tool.sql.ooaofooa.association.impl.ClassAsSupertypeSetImpl;
import io.ciera.tool.sql.ooaofooa.association.impl.ClassInAssociationSetImpl;
import io.ciera.tool.sql.ooaofooa.subsystem.ClassIdentifierSet;
import io.ciera.tool.sql.ooaofooa.subsystem.ReferredToIdentifierAttributeSet;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.ClassIdentifierSetImpl;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.ReferredToIdentifierAttributeSetImpl;

import java.util.Arrays;
import java.util.List;


public class ReferredToClassInAssocSetImpl extends InstanceSet<ReferredToClassInAssocSet,ReferredToClassInAssoc> implements ReferredToClassInAssocSet {

    // attributes
    @Override
    public void setOIR_ID( UniqueId ref_OIR_ID ) throws XtumlException {
        for ( ReferredToClassInAssoc referredtoclassinassoc : this ) referredtoclassinassoc.setOIR_ID( ref_OIR_ID );
    }
    @Override
    public void setOid_ID( int ref_Oid_ID ) throws XtumlException {
        for ( ReferredToClassInAssoc referredtoclassinassoc : this ) referredtoclassinassoc.setOid_ID( ref_Oid_ID );
    }
    @Override
    public void setRel_ID( UniqueId ref_Rel_ID ) throws XtumlException {
        for ( ReferredToClassInAssoc referredtoclassinassoc : this ) referredtoclassinassoc.setRel_ID( ref_Rel_ID );
    }
    @Override
    public void setObj_ID( UniqueId ref_Obj_ID ) throws XtumlException {
        for ( ReferredToClassInAssoc referredtoclassinassoc : this ) referredtoclassinassoc.setObj_ID( ref_Obj_ID );
    }


    // selections
    @Override
    public ClassIdentifierSet R109_is_identified_in_this_association_by_ClassIdentifier() throws XtumlException {
        ClassIdentifierSet classidentifierset = new ClassIdentifierSetImpl();
        for ( ReferredToClassInAssoc referredtoclassinassoc : this ) classidentifierset.add( referredtoclassinassoc.R109_is_identified_in_this_association_by_ClassIdentifier() );
        return classidentifierset;
    }
    @Override
    public ReferredToIdentifierAttributeSet R110_is_identified_in_this_association_by_ReferredToIdentifierAttribute() throws XtumlException {
        ReferredToIdentifierAttributeSet referredtoidentifierattributeset = new ReferredToIdentifierAttributeSetImpl();
        for ( ReferredToClassInAssoc referredtoclassinassoc : this ) referredtoidentifierattributeset.addAll( referredtoclassinassoc.R110_is_identified_in_this_association_by_ReferredToIdentifierAttribute() );
        return referredtoidentifierattributeset;
    }
    @Override
    public ClassInAssociationSet R203_is_a_ClassInAssociation() throws XtumlException {
        ClassInAssociationSet classinassociationset = new ClassInAssociationSetImpl();
        for ( ReferredToClassInAssoc referredtoclassinassoc : this ) classinassociationset.add( referredtoclassinassoc.R203_is_a_ClassInAssociation() );
        return classinassociationset;
    }
    @Override
    public ClassAsAssociatedOneSideSet R204_is_a_ClassAsAssociatedOneSide() throws XtumlException {
        ClassAsAssociatedOneSideSet classasassociatedonesideset = new ClassAsAssociatedOneSideSetImpl();
        for ( ReferredToClassInAssoc referredtoclassinassoc : this ) classasassociatedonesideset.add( referredtoclassinassoc.R204_is_a_ClassAsAssociatedOneSide() );
        return classasassociatedonesideset;
    }
    @Override
    public ClassAsAssociatedOtherSideSet R204_is_a_ClassAsAssociatedOtherSide() throws XtumlException {
        ClassAsAssociatedOtherSideSet classasassociatedothersideset = new ClassAsAssociatedOtherSideSetImpl();
        for ( ReferredToClassInAssoc referredtoclassinassoc : this ) classasassociatedothersideset.add( referredtoclassinassoc.R204_is_a_ClassAsAssociatedOtherSide() );
        return classasassociatedothersideset;
    }
    @Override
    public ClassAsSimpleParticipantSet R204_is_a_ClassAsSimpleParticipant() throws XtumlException {
        ClassAsSimpleParticipantSet classassimpleparticipantset = new ClassAsSimpleParticipantSetImpl();
        for ( ReferredToClassInAssoc referredtoclassinassoc : this ) classassimpleparticipantset.add( referredtoclassinassoc.R204_is_a_ClassAsSimpleParticipant() );
        return classassimpleparticipantset;
    }
    @Override
    public ClassAsSupertypeSet R204_is_a_ClassAsSupertype() throws XtumlException {
        ClassAsSupertypeSet classassupertypeset = new ClassAsSupertypeSetImpl();
        for ( ReferredToClassInAssoc referredtoclassinassoc : this ) classassupertypeset.add( referredtoclassinassoc.R204_is_a_ClassAsSupertype() );
        return classassupertypeset;
    }


    @Override
    public ReferredToClassInAssoc nullElement() {
        return ReferredToClassInAssocImpl.EMPTY_REFERREDTOCLASSINASSOC;
    }

    @Override
    public ReferredToClassInAssocSet emptySet() {
      return new ReferredToClassInAssocSetImpl();
    }

    @Override
    public ReferredToClassInAssocSet value() {
        return this;
    }

    @Override
    public List<ReferredToClassInAssoc> elements() {
        return Arrays.asList(toArray(new ReferredToClassInAssoc[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/association/impl/ReferredToClassInAssocSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.association.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.association.ClassAsAssociatedOneSideSet;
import io.ciera.tool.sql.ooaofooa.association.ClassAsAssociatedOtherSideSet;
import io.ciera.tool.sql.ooaofooa.association.ClassAsSimpleParticipantSet;
import io.ciera.tool.sql.ooaofooa.association.ClassAsSupertypeSet;
import io.ciera.tool.sql.ooaofooa.association.ClassInAssociationSet;
import io.ciera.tool.sql.ooaofooa.association.ReferredToClassInAssoc;
import io.ciera.tool.sql.ooaofooa.association.ReferredToClassInAssocSet;
import io.ciera.tool.sql.ooaofooa.association.impl.ClassAsAssociatedOneSideSetImpl;
import io.ciera.tool.sql.ooaofooa.association.impl.ClassAsAssociatedOtherSideSetImpl;
import io.ciera.tool.sql.ooaofooa.association.impl.ClassAsSimpleParticipantSetImpl;
import io.ciera.tool.sql.ooaofooa.association.impl.ClassAsSupertypeSetImpl;
import io.ciera.tool.sql.ooaofooa.association.impl.ClassInAssociationSetImpl;
import io.ciera.tool.sql.ooaofooa.subsystem.ClassIdentifierSet;
import io.ciera.tool.sql.ooaofooa.subsystem.ReferredToIdentifierAttributeSet;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.ClassIdentifierSetImpl;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.ReferredToIdentifierAttributeSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class ReferredToClassInAssocSetImpl extends InstanceSet<ReferredToClassInAssocSet,ReferredToClassInAssoc> implements ReferredToClassInAssocSet {

    public ReferredToClassInAssocSetImpl() {
    }

    public ReferredToClassInAssocSetImpl(Comparator<? super ReferredToClassInAssoc> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setObj_ID( UniqueId ref_Obj_ID ) throws XtumlException {
        for ( ReferredToClassInAssoc referredtoclassinassoc : this ) referredtoclassinassoc.setObj_ID( ref_Obj_ID );
    }
    @Override
    public void setOIR_ID( UniqueId ref_OIR_ID ) throws XtumlException {
        for ( ReferredToClassInAssoc referredtoclassinassoc : this ) referredtoclassinassoc.setOIR_ID( ref_OIR_ID );
    }
    @Override
    public void setOid_ID( int ref_Oid_ID ) throws XtumlException {
        for ( ReferredToClassInAssoc referredtoclassinassoc : this ) referredtoclassinassoc.setOid_ID( ref_Oid_ID );
    }
    @Override
    public void setRel_ID( UniqueId ref_Rel_ID ) throws XtumlException {
        for ( ReferredToClassInAssoc referredtoclassinassoc : this ) referredtoclassinassoc.setRel_ID( ref_Rel_ID );
    }


    // selections
    @Override
    public ClassIdentifierSet R109_is_identified_in_this_association_by_ClassIdentifier() throws XtumlException {
        ClassIdentifierSet classidentifierset = new ClassIdentifierSetImpl();
        for ( ReferredToClassInAssoc referredtoclassinassoc : this ) classidentifierset.add( referredtoclassinassoc.R109_is_identified_in_this_association_by_ClassIdentifier() );
        return classidentifierset;
    }
    @Override
    public ReferredToIdentifierAttributeSet R110_is_identified_in_this_association_by_ReferredToIdentifierAttribute() throws XtumlException {
        ReferredToIdentifierAttributeSet referredtoidentifierattributeset = new ReferredToIdentifierAttributeSetImpl();
        for ( ReferredToClassInAssoc referredtoclassinassoc : this ) referredtoidentifierattributeset.addAll( referredtoclassinassoc.R110_is_identified_in_this_association_by_ReferredToIdentifierAttribute() );
        return referredtoidentifierattributeset;
    }
    @Override
    public ClassInAssociationSet R203_is_a_ClassInAssociation() throws XtumlException {
        ClassInAssociationSet classinassociationset = new ClassInAssociationSetImpl();
        for ( ReferredToClassInAssoc referredtoclassinassoc : this ) classinassociationset.add( referredtoclassinassoc.R203_is_a_ClassInAssociation() );
        return classinassociationset;
    }
    @Override
    public ClassAsAssociatedOneSideSet R204_is_a_ClassAsAssociatedOneSide() throws XtumlException {
        ClassAsAssociatedOneSideSet classasassociatedonesideset = new ClassAsAssociatedOneSideSetImpl();
        for ( ReferredToClassInAssoc referredtoclassinassoc : this ) classasassociatedonesideset.add( referredtoclassinassoc.R204_is_a_ClassAsAssociatedOneSide() );
        return classasassociatedonesideset;
    }
    @Override
    public ClassAsAssociatedOtherSideSet R204_is_a_ClassAsAssociatedOtherSide() throws XtumlException {
        ClassAsAssociatedOtherSideSet classasassociatedothersideset = new ClassAsAssociatedOtherSideSetImpl();
        for ( ReferredToClassInAssoc referredtoclassinassoc : this ) classasassociatedothersideset.add( referredtoclassinassoc.R204_is_a_ClassAsAssociatedOtherSide() );
        return classasassociatedothersideset;
    }
    @Override
    public ClassAsSimpleParticipantSet R204_is_a_ClassAsSimpleParticipant() throws XtumlException {
        ClassAsSimpleParticipantSet classassimpleparticipantset = new ClassAsSimpleParticipantSetImpl();
        for ( ReferredToClassInAssoc referredtoclassinassoc : this ) classassimpleparticipantset.add( referredtoclassinassoc.R204_is_a_ClassAsSimpleParticipant() );
        return classassimpleparticipantset;
    }
    @Override
    public ClassAsSupertypeSet R204_is_a_ClassAsSupertype() throws XtumlException {
        ClassAsSupertypeSet classassupertypeset = new ClassAsSupertypeSetImpl();
        for ( ReferredToClassInAssoc referredtoclassinassoc : this ) classassupertypeset.add( referredtoclassinassoc.R204_is_a_ClassAsSupertype() );
        return classassupertypeset;
    }


    @Override
    public ReferredToClassInAssoc nullElement() {
        return ReferredToClassInAssocImpl.EMPTY_REFERREDTOCLASSINASSOC;
    }

    @Override
    public ReferredToClassInAssocSet emptySet() {
      return new ReferredToClassInAssocSetImpl();
    }

    @Override
    public ReferredToClassInAssocSet emptySet(Comparator<? super ReferredToClassInAssoc> comp) {
      return new ReferredToClassInAssocSetImpl(comp);
    }

    @Override
    public ReferredToClassInAssocSet value() {
        return this;
    }

    @Override
    public List<ReferredToClassInAssoc> elements() {
        return Arrays.asList(toArray(new ReferredToClassInAssoc[0]));
    }

}
